summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorpquerna <pquerna@13f79535-47bb-0310-9956-ffa450edef68>2005-03-15 22:41:02 +0000
committerpquerna <pquerna@13f79535-47bb-0310-9956-ffa450edef68>2005-03-15 22:41:02 +0000
commite6604430e0de6cc9215d205f6b1502728b6b8da1 (patch)
tree5e24b47f61e1cd51e15e3b62c10b5b23ed661241 /include
parent50c113d3e75648f5560849ca9a5ae682f5787015 (diff)
downloadlibapr-e6604430e0de6cc9215d205f6b1502728b6b8da1.tar.gz
Backport r153917 and r153932 from trunk. Build fixes for multicast on Tru64 and HP-UX.
git-svn-id: http://svn.apache.org/repos/asf/apr/apr/branches/1.1.x@157601 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include')
-rw-r--r--include/apr_network_io.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/apr_network_io.h b/include/apr_network_io.h
index 9df0ec29c..c7575d74f 100644
--- a/include/apr_network_io.h
+++ b/include/apr_network_io.h
@@ -770,14 +770,14 @@ APR_DECLARE(apr_status_t) apr_mcast_join(apr_socket_t *sock,
* Leave a Multicast Group. All arguments must be the same as
* apr_mcast_join.
* @param sock The socket to leave a multicast group
* @param leave The address of the multicast group to leave
* @param iface Address of the interface to use. If NULL is passed, the
* default multicast interface will be used. (OS Dependent)
* @param source Source Address to accept transmissions from (non-NULL
* implies Source-Specific Multicast)
*/
APR_DECLARE(apr_status_t) apr_mcast_leave(apr_socket_t *sock,
- apr_sockaddr_t *leave,
+ apr_sockaddr_t *addr,
apr_sockaddr_t *iface,
apr_sockaddr_t *source);
@@ -770,14 +770,14 @@ APR_DECLARE(apr_status_t) apr_mcast_join(apr_socket_t *sock,
* apr_mcast_join.
* @param sock The socket to leave a multicast group
- * @param leave The address of the multicast group to leave
+ * @param addr The address of the multicast group to leave
* @param iface Address of the interface to use. If NULL is passed, the
* default multicast interface will be used. (OS Dependent)